Introduction
============

This package contains various visual components for Plone, such as viewlets
and general views.

Since version 2.3.2 and up, this product only works on Plone 4.3 or higher.

